@@ -36,6 +36,7 @@ from .models import (
     ProjectList,
     ProjectPost,
     User,
+    TemplateDownloadInfo,
 )
 from .notebook import Notebook
 from .utils import filename_to_title, title_to_name, update_query
@@ -82,6 +83,9 @@ ME_URL = "{api_url}/my/user"
 USERS_URL = "{api_url}/users/{user_id}"
 PROJECTS_URL = "{api_url}/projects"
 UPLOAD_URL = "{api_url}/my/upload"
+TEMPLATES_URL = "{api_url}/templates"
+TEMPLATE_URL = "{api_url}/templates/{id}"
+TEMPLATE_DOWNLOAD_URL = "{api_url}/templates/{id}/download"
 
 
 class Session:
@@ -100,13 +104,13 @@ class Session:
         )
 
     @lru_cache(maxsize=128)
-    def _get(self, url: str) -> requests.Response:
+    def _get(self, url: str, stream=False) -> requests.Response:
         resp = self._session.get(url)
         if resp.status_code >= 400:
             raise ValueError(resp.content)
         return resp
 
-    def _get_model(self, url: str, model: Type[BaseModel]) -> BaseModel:
+    def get_model(self, url: str, model: Type[BaseModel]) -> BaseModel:
         resp = self._get(url)
         return model(**resp.json())
 
@@ -135,6 +139,13 @@ class Session:
         self._get.cache_clear()
         return resp
 
+    def get_template_download_link(self, template_id: str):
+        """
+            Return the tempalte metadata based on id
+        """
+        info = self.get_model(TEMPLATE_DOWNLOAD_URL.format(api_url=self.api_url, id=template_id), TemplateDownloadInfo)
+        return info.link
+
     def user(self) -> MyUser:
         """User object corresponding to session user
 
@@ -238,7 +249,7 @@ class Session:
             raise ValueError(
                 f"trying to fetch version {version} when latest version is {block.latest_version}"
             )
-        version_obj = self._get_model(
+        version_obj = self.get_model(
             f"{block.links.self}/versions/{version}", BlockVersion
         )
         return version_obj
@@ -255,7 +266,7 @@ class Session:
             )
         try:
             url = f"{block.links.self}/versions/{version}/children/?format={fmt}"
-            return self._get_model(url, ChildrenList)
+            return self.get_model(url, ChildrenList)
         except ValueError as err:
             logging.error(f"Failed to fetch children {url}")
             raise err
