@@ -1,14 +1,13 @@
-from curvenote.latex.utils.links import minimise_oxa_path
-from curvenote.latex.utils.regex import REF_COMMAND_OXA_REGEX
-from curvenote.latex.utils.index import LocalMarker
 import re
 import logging
-from .utils import LocalReferenceItem
+import json
+from .utils import LocalMarker, minimise_oxa_path
+from .utils.regex import REF_COMMAND_OXA_REGEX
 from typing import List, Optional, Union
 from ..client import Session
 from ..models import Block, BlockFormat, BlockKind, BlockVersion, ChildrenList, Project
 from . import utils
-from .block_version import LatexBlockVersion
+from .BlockVersion import LatexBlockVersion
 
 logger = logging.getLogger()
 
@@ -27,7 +26,7 @@ class LatexArticle:
         self.article_id = article_id
         self.block: Block = None
         self.version: BlockVersion = None
-        self.children: ChildrenList = None
+        self.child_versions: List[BlockVersion] = None
         self.content: str = ""
         # TODO obvious one to centralise in project or someway
         self.users = []
@@ -76,7 +75,7 @@ class LatexArticle:
         return f"{base}/oxa:{v.id.project}/{v.id.block}.{v.id.version}"
 
 
-    def fetch(self, version: Optional[int] = None):
+    def fetch(self, fmt: BlockFormat, version: Optional[int] = None):
         """Download article and all children in Latex format
 
         Raises ValueError if download fails.
@@ -88,7 +87,7 @@ class LatexArticle:
         logging.info("article.fetch got block")
         version_to_fetch = version or block.latest_version
         children = self.session.get_version_with_children(
-            block, version_to_fetch, fmt=BlockFormat.tex
+            block, version_to_fetch, fmt
         )
         if len(children.errors) > 0:
             logger.error("There were errors fetching some children")
@@ -98,7 +97,7 @@ class LatexArticle:
         if children.versions.items[0].kind != BlockKind.article:
             raise ValueError("Expected first child to be an article")
         self.block = children.blocks.items[0]
-        self.version, *self.children = children.versions.items
+        self.version, *self.child_versions = children.versions.items
         logger.info(
             f"Processing Article: {self.version.id.project}/"
             f"{self.version.id.block}/versions/{self.version.id.version}"
@@ -109,7 +108,7 @@ class LatexArticle:
         self,
         session: Session,
         assets_folder: str,
-        reference_list: List[LocalReferenceItem],
+        reference_list: List[LocalMarker],
         figure_list: List[LocalMarker],
     ):
         """
@@ -172,12 +171,12 @@ class LatexArticle:
         """
         logging.info("Localized content and references")
         concatenated_content = ""
-        for i, child in enumerate(self.children):
+        for i, child in enumerate(self.child_versions):
             # pylint: disable=broad-except
-            block = LatexBlockVersion(session, child)
+            block = LatexBlockVersion(session, assets_folder, reference_list, figure_list, child)
 
             try:
-                block.localize(assets_folder, reference_list, figure_list)
+                block.localize()
                 if i == 0:
                     concatenated_content += f"{block.content}\n"
                 else:
