@@ -11,11 +11,11 @@ from .localize_images import ImageFormats
 
 
 def get_image_block(
-    session: Session, assets_folder: str, oxa_path: str, local_path: str
+    session: Session, assets_folder: str, oxa_path: str, local_path: str, fmt: BlockFormat
 ):
-    url = oxa_path_to_api_url(session.api_url, oxa_path, BlockFormat.tex)
+    url = oxa_path_to_api_url(session.api_url, oxa_path, fmt)
     logging.info("fetching image block from %s", url)
-    image_block = session._get_model(url, BlockVersion)
+    image_block = session.get_model(url, BlockVersion)
     if not image_block:
         raise ValueError(f"Could not fetch image block {url}")
 
