@@ -1,4 +1,12 @@
 import logging
+import re
+import time
+from collections import namedtuple
+from typing import List, NamedTuple, Optional, Union
+
+from ...client import Session
+from ...models import Block, BlockFormat, BlockVersion
+from .regex import INLINE_CITATION_BLOCK_REGEX
 import requests
 from collections import namedtuple
 from typing import NamedTuple
@@ -7,19 +15,16 @@ from ...models import BlockVersion
 
 logger = logging.getLogger()
 
-LocalReferenceItem = namedtuple(
-    "LocalReferenceItem", ["block_path", "local_tag", "bibtex"]
-)
-
 class LocalMarker(NamedTuple):
     marker: str
     local_path: str
     remote_path: str
+    content: Optional[str]
 
 
 # TODO move to session - easier to mock
 def get_model(session, url, model=BlockVersion):
-    block = session._get_model(url, model)
+    block = session.get_model(url, model)
     if not block:
         raise ValueError(f"Could not fetch the block {url}")
     return block
