@@ -116,6 +116,14 @@ class PathSpec(BaseModel):
     block: Optional[str]
     version: Optional[int]
 
+class SrcID(VersionID):
+    draft: str
+
+class PathSpec(BaseModel):
+    team: str
+    project: Optional[str]
+    block: Optional[str]
+    version: Optional[int]
 
 class BlockLinks(SelfLinks):
     project: AnyHttpUrl
@@ -197,6 +205,7 @@ class BlockFormat(str, Enum):
     md = "md"
     jupyter = "jupyter"
     tex = "tex"
+    tex_curvenote = "tex:curvenote"
     json = "json"
     bibtex = "bibtex"
 
@@ -435,3 +444,6 @@ class ChildrenList(BaseModel):
     blocks: ItemList[Block]
     versions: ItemList[BlockVersion]
     errors: List
+
+class TemplateDownloadInfo(BaseModel):
+    link: AnyHttpUrl
